| Title: | Write SQL Statements with ease |
|---|---|
| Description: | This package provides a set of utility functions to efficiently write SQL Statements: In essence converting R to SQL. |
| Authors: | Flippie Coetser [aut, cre] (ORCID: <https://orcid.org/0000-0003-0549-9245>) |
| Maintainer: | Flippie Coetser <[email protected]> |
| License: | file LICENSE |
| Version: | 0.0.1.300 |
| Built: | 2026-05-21 08:16:39 UTC |
| Source: | https://github.com/FlippieCoetser/Query |
DML is a subset or SQL and used to manipulating data in SQL Database
A list of DML Services:
INSERT()
INTO()
SCHEMA(schema)
TABLE(table)
VALUES()
KEYS(keyValues)
NEWVALUES(keyValues)
UPDATE()
SET()
KEYVALUES(keyValues)
DELETE()
DQL is a subset or SQL and used to perform queries against tables in SQL Database
A list of DQL Services:
SELECT()
FROM()
WHERE()
Generate SQL statement during runtime.
A list of utility functions:
SQL contains a set of Utility Functions used to perform primitive operations
A list of SQL Functions:
LOWER(value, alias)
a collection of services used to construct SQL Queries during runtime
A list of services:
SELECT(fields)
FROM(table)
WHERE(key, value)
INSERT(table, keyValues)
VALUES(keyValues)
UPDATE(table)
SET(keyValues)
DELETE()
Generate SQL statement during runtime.
A list of utility functions:
Utility services not included in the standard set of SQL functions and used to perform primitive operations
A list of Helper Utilities:
BRACKET(value)